import os
import argparse
import pathlib
from PIL import Image

parser = argparse.ArgumentParser()
parser.add_argument("webp", type=pathlib.Path, help="folder where all .webp files are located")
parser.add_argument("gif", type=pathlib.Path, help="folder where all previous .gif files are located")
args = parser.parse_args()

# Get all converted gifs names
all_gifs = os.listdir(args.gif)

# Get all file names without .gif extension
all_gifs = [name[:-4] for name in all_gifs]

# Get all files in webp folder
files = os.listdir(args.webp)

# Maintain only .webp files
files = [file for file in files if file[-5:] == '.webp']

for file in files:
    if file[:-5] not in all_gifs:
        image = Image.open(pathlib.Path.joinpath(args.webp, file))
        image.save(pathlib.Path.joinpath(args.gif, f"{file[:-5]}.gif"), 'gif', save_all=True, background=0)




from distutils.core import setup
setup(
  name='gifering',
  packages=['gifering'],
  version='0.1',
  license='MIT',
  description='A cli application to convert a bunch of .webp files into .gif files',
  author='André Carvalho',
  author_email='alac1984@gmail.com',
  url='https://github.com/alac1984/gifering',
  download_url='https://github.com/alac1984/gifering/archive/refs/tags/0.1.tar.gz',
  keywords=['converter', 'webp', 'gif'],
  install_requires=[
          'pillow',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.10',
  ],
)
